@@ -3,10 +3,14 @@
 extern crate test;
 
 use rand::{thread_rng, Rng};
-use solana_core::broadcast_stage::broadcast_metrics::TransmitShredsStats;
-use solana_core::broadcast_stage::{broadcast_shreds, get_broadcast_peers};
-use solana_gossip::cluster_info::{ClusterInfo, Node};
-use solana_gossip::contact_info::ContactInfo;
+use solana_core::{
+    broadcast_stage::{broadcast_metrics::TransmitShredsStats, broadcast_shreds, BroadcastStage},
+    cluster_nodes::ClusterNodes,
+};
+use solana_gossip::{
+    cluster_info::{ClusterInfo, Node},
+    contact_info::ContactInfo,
+};
 use solana_ledger::shred::Shred;
 use solana_sdk::pubkey;
 use solana_sdk::timing::timestamp;
@@ -36,7 +40,7 @@ fn broadcast_shreds_bench(bencher: &mut Bencher) {
         stakes.insert(id, thread_rng().gen_range(1, NUM_PEERS) as u64);
     }
     let cluster_info = Arc::new(cluster_info);
-    let (peers, peers_and_stakes) = get_broadcast_peers(&cluster_info, Some(&stakes));
+    let cluster_nodes = ClusterNodes::<BroadcastStage>::new(&cluster_info, &stakes);
     let shreds = Arc::new(shreds);
     let last_datapoint = Arc::new(AtomicU64::new(0));
     bencher.iter(move || {
@@ -44,8 +48,7 @@ fn broadcast_shreds_bench(bencher: &mut Bencher) {
         broadcast_shreds(
             &socket,
             &shreds,
-            &peers_and_stakes,
-            &peers,
+            &cluster_nodes,
             &last_datapoint,
             &mut TransmitShredsStats::default(),
         )
